@@ -43,7 +43,7 @@ describe 'glance::backend::vsphere' do
         is_expected.to contain_glance_api_config('glance_store/vmware_insecure').with_value('True')
         is_expected.to contain_glance_api_config('glance_store/vmware_server_host').with_value('10.0.0.1')
         is_expected.to contain_glance_api_config('glance_store/vmware_server_username').with_value('root')
-        is_expected.to contain_glance_api_config('glance_store/vmware_server_password').with_value('123456')
+        is_expected.to contain_glance_api_config('glance_store/vmware_server_password').with_value('123456').with_secret(true)
         is_expected.to contain_glance_api_config('glance_store/vmware_store_image_dir').with_value('/openstack_glance')
         is_expected.to contain_glance_api_config('glance_store/vmware_task_poll_interval').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_api_config('glance_store/vmware_api_retry_count').with_value('<SERVICE DEFAULT>')
@@ -55,7 +55,7 @@ describe 'glance::backend::vsphere' do
         is_expected.to_not contain_glance_glare_config('glance_store/vmware_insecure').with_value('True')
         is_expected.to_not contain_glance_glare_config('glance_store/vmware_server_host').with_value('10.0.0.1')
         is_expected.to_not contain_glance_glare_config('glance_store/vmware_server_username').with_value('root')
-        is_expected.to_not contain_glance_glare_config('glance_store/vmware_server_password').with_value('123456')
+        is_expected.to_not contain_glance_glare_config('glance_store/vmware_server_password').with_value('123456').with_secret(true)
         is_expected.to_not contain_glance_glare_config('glance_store/vmware_store_image_dir').with_value('/openstack_glance')
         is_expected.to_not contain_glance_glare_config('glance_store/vmware_task_poll_interval').with_value('<SERVICE DEFAULT>')
         is_expected.to_not contain_glance_glare_config('glance_store/vmware_api_retry_count').with_value('<SERVICE DEFAULT>')
